@@ -9,6 +9,8 @@ import warnings
 
 from google.cloud import storage
 from google.cloud import bigquery
+from google.api_core import exceptions
+from google.api_core.retry import Retry
 from google.cloud.exceptions import NotFound
 import google.oauth2
 import pandas_gbq
@@ -19,6 +21,18 @@ from azure.storage.blob import BlobServiceClient
 
 import pandas as pd
 
+_MY_RETRIABLE_TYPES = [
+   exceptions.TooManyRequests,  # 429
+   exceptions.InternalServerError,  # 500
+   exceptions.BadGateway,  # 502
+   exceptions.ServiceUnavailable,  # 503
+]
+
+def is_retryable(exc):
+    return True#isinstance(exc, _MY_RETRIABLE_TYPES)
+
+my_retry_policy = Retry(predicate=is_retryable)
+
 class GoogleBigQuery:
     
     def __init__(
@@ -210,7 +224,7 @@ class GoogleCloudStorage:
 
     def get_blob(self, bucket_name, object_name):
     
-        bucket = self.storage_client.get_bucket(bucket_name)
+        bucket = self.storage_client.get_bucket(bucket_name, retry=my_retry_policy, timeout=(10, 30))
         blob = bucket.blob(object_name)
         return blob
 
@@ -227,7 +241,7 @@ class GoogleCloudStorage:
             add = 0 if directory[-1] == '/' else 1
             n = len(directory) + add # added 1 for the '/'
         
-        bucket = self.storage_client.get_bucket(bucket_name)
+        bucket = self.storage_client.get_bucket(bucket_name, retry=my_retry_policy, timeout=(10, 30))
         blobs = bucket.list_blobs(prefix=directory)
 
         blobs = [blob.name[n:] or '.' for blob in blobs]
@@ -249,7 +263,7 @@ class GoogleCloudStorage:
 
         bucket_name, object_name = self._split_uri(dest_filename)
         #print(bucket_name, object_name)
-        bucket = self.storage_client.get_bucket(bucket_name)
+        bucket = self.storage_client.get_bucket(bucket_name, retry=my_retry_policy, timeout=(10, 30))
         blob = bucket.blob(object_name)
         #print(source_filename)
         blob.upload_from_filename(source_filename)
@@ -395,7 +409,7 @@ class GoogleCloudStorage:
         pickle_str = pickle.dumps(obj)
         
         bucket_name, object_name = self._split_uri(dest_filename)
-        bucket = self.storage_client.get_bucket(bucket_name)
+        bucket = self.storage_client.get_bucket(bucket_name, retry=my_retry_policy, timeout=(10, 30))
         blob = bucket.blob(object_name)
         print('Uploading to {}...'.format(dest_filename))
         blob.upload_from_string(pickle_str)
@@ -426,7 +440,7 @@ class GoogleCloudStorage:
 
         temp_filename = shutil.make_archive('_tmp', extension, directory)
 
-        bucket = self.storage_client.get_bucket(bucket_name)
+        bucket = self.storage_client.get_bucket(bucket_name, retry=my_retry_policy, timeout=(10, 30))
         blob = bucket.blob(object_name)
         blob.upload_from_filename(temp_filename)
 
