@@ -24,7 +24,8 @@ class CopernicaREST:
         # Just a random string
         self.state = 'sjDIEj39fkDSUo40'
         
-    def get_auth_url(self, client_id = '352576017e08e77410efc978040b7e7d', client_secret = 'dc0ac7e6d01998f78a92850835004d3d'):
+    #Directondergoed: def get_auth_url(self, client_id = '352576017e08e77410efc978040b7e7d', client_secret = 'dc0ac7e6d01998f78a92850835004d3d'):
+    def get_auth_url(self, client_id, client_secret):
         
         copernica = OAuth2Service(
             client_id=client_id,
@@ -246,10 +247,37 @@ class CopernicaPredictionsLoader:
         self.humai_database_id = -1
         self.humai_collection_id = -1
         
-    def create_or_init(self, database='HumaiTestDB', humai_pred_collection = 'HumaiPredictions'):
+        self.profile_fields = [
+            ('Humai_Customer_ID','text','',True),
+            ('Humai_Group','text','',True)
+        ]
         
+        self.subprofile_fields = [
+            ('Humai_Customer_ID','text','',True),
+            ('Humai_Mail_ID','integer',-1,True),
+            ('Type','text','PersonalizedMailFlow',True),
+            ('Date','date','2020-01-01',True),
+            ('DatetimeSlot','text','Midnightto12PM', True),
+            ('Group','text','A',True)
+        ]
+        
+        
+    def create_or_init(
+        self, 
+        database,
+        humai_pred_collection = 'Humai_Predictions',
+        profile_fields = None,
+        subprofile_fields = None
+    ):
+        if profile_fields is not None:
+            self.profile_fields = profile_fields
+            
+        if subprofile_fields is not None:
+            self.subprofile_fields = subprofile_fields
+            
         self._create_fields_and_collection(database, humai_pred_collection)
         
+        
     def _create_elements(self, endpoint, df):
     
         _, data = self.api.get(endpoint)
@@ -283,12 +311,7 @@ class CopernicaPredictionsLoader:
         self.humai_collection_id = -1
         self.ready = False
         
-        required_fields = [
-            ('Humai_Customer_ID','text','',True),
-            ('Humai_Group','text','',True)
-        ]
-
-        df_fields = pd.DataFrame(required_fields, columns=['name','type','value','displayed'])
+        df_fields = pd.DataFrame(self.profile_fields, columns=['name','type','value','displayed'])
 
         required_interests = [
         #    ('OS_1', 'Humai_Interests'),
@@ -298,16 +321,7 @@ class CopernicaPredictionsLoader:
 
         df_interests = pd.DataFrame(required_interests, columns=['name','group'])
 
-        required_collection_fields = [
-            ('Humai_Customer_ID','text','',True),
-            ('Humai_Mail_ID','integer',-1,True),
-            ('Type','text','PersonalizedMailFlow',True),
-            ('Date','date','2020-01-01',True),
-            ('DatetimeSlot','text','Midnightto12PM', True),
-            ('Group','text','A',True)
-        ]
-
-        df_collection_fields = pd.DataFrame(required_collection_fields, columns=['name','type','value','displayed'])
+        df_collection_fields = pd.DataFrame(self.subprofile_fields, columns=['name','type','value','displayed'])
         
         ## Creation logic
         
@@ -677,6 +691,13 @@ class CopernicaCustomersExtract:
         self.df_customers = None
         self.gbq = gbq
         self.api = CopernicaREST(access_token)
+        self.fieldnames = {
+            'firstname' : 'MFirstName',
+            'lastname' : 'MLastName',
+            'email' : 'MEmail',
+            'gender' : 'MGender',
+            'dob' : 'MDOB',
+        }
         
         return
     
@@ -688,7 +709,15 @@ class CopernicaCustomersExtract:
         
         return int(record[field_name]) if field_name in record else np.nan
     
-    def extract(self, database='', page_size=1000):
+    def _unsubscribed(self, fields):
+        
+        return self._extract_string(fields, 'MSubscriberRawState') != 'STATUS_SUBSCRIBED' or self._extract_string(fields, 'MNewsletter') != 'YES' or self._extract_string(fields, 'AfgemeldNieuwsbrief') == 'JA'
+
+    def set_fieldnames(self, fieldnames):
+        
+        self.fieldnames = fieldnames        
+    
+    def extract(self, database='', page_size=1000, verbose=False):
         
         if self.api is None:
             print("[CopernicaCustomersExtract::extract] No API.")
@@ -714,6 +743,7 @@ class CopernicaCustomersExtract:
             if 200 <= response.status_code <= 299:
 
                 total_profiles = data['total']
+                #print(data)
 
                 for profile in data['data']:
 
@@ -727,21 +757,24 @@ class CopernicaCustomersExtract:
                         fields = profile['fields']
                         #print("fields:\n============")
                         #print(fields)
-                        cfirstname = self._extract_string(fields, 'MFirstName')
-                        clastname = self._extract_string(fields, 'MLastName')
-                        cemail = self._extract_string(fields, 'MEmail')
+                        cfirstname = self._extract_string(fields, self.fieldnames['firstname'])
+                        clastname = self._extract_string(fields, self.fieldnames['lastname'])
+                        cemail = self._extract_string(fields, self.fieldnames['email'])
                         copernica_id = int( profile['ID'] )
 
-                        unsub = profile['removed'] or self._extract_string(fields, 'MSubscriberRawState') != 'STATUS_SUBSCRIBED' or self._extract_string(fields, 'MNewsletter') != 'YES' or self._extract_string(fields, 'AfgemeldNieuwsbrief') == 'JA'
-
+                        unsub = profile['removed'] or self._unsubscribed(fields)
+                        
                         customer_rows.append((
                             copernica_id,cemail,
                             cfirstname,clastname,
-                            self._extract_string(fields, 'MDOB'),
-                            self._extract_string(fields, 'MGender'),
+                            self._extract_string(fields, self.fieldnames['dob']),
+                            self._extract_string(fields, self.fieldnames['gender']),
                             not unsub
                         ))
                         
+                        if verbose:
+                            print(f"{copernica_id}, {cemail}, {cfirstname}, {clastname}")
+                        
                     cur_profile = 1 + cur_profile
             else:
                 cur_profile = page_size + cur_profile
@@ -760,5 +793,104 @@ class CopernicaCustomersExtract:
         )
 
         return df_customers
+
+class CopernicaSelectionExtract:
+    """
+    Helper class for converting between Customer IDs and Copernica IDs, given a customers table.
+    """
     
-     
\ No newline at end of file
+    def __init__(self, gbq, access_token):
+        
+        self.df_customers = None
+        self.gbq = gbq
+        self.api = CopernicaREST(access_token)
+        self.fieldnames = {
+            'copernica_id' : 'ID',
+            'email' : 'email',
+            'Customer_ID' : 'Humai_Customer_ID',
+            'Group' : 'Humai_Group',
+        }
+        
+        return
+    
+    def _extract_string(self, record, field_name):
+        
+        return record[field_name].strip().upper() if field_name in record else ''
+    
+    def _extract_int(self, record, field_name):
+        
+        return int(record[field_name]) if field_name in record else np.nan
+    
+    def set_fieldnames(self, fieldnames):
+        
+        self.fieldnames = fieldnames        
+    
+    def extract(self, view_id='', page_size=1000, verbose=False):
+        
+        if self.api is None:
+            print("[CopernicaCustomersExtract::extract] No API.")
+            return None
+
+        #database_id = get_database_id(self.api, database)
+        #if database_id < 0:
+        #    if verbose:
+        #        print("[CopernicaCustomersExtract::extract] Failed to find database {}".format(database))
+        #    return None
+        
+        customer_rows = []
+        
+        cur_profile = 0
+        total_profiles = 1
+        while cur_profile < total_profiles:
+
+            parameters = {
+                'start' : cur_profile,
+                'limit' : page_size
+            }
+            response, data = self.api.get('view/{}/profiles'.format(view_id), params=parameters, verbose=False)
+            if 200 <= response.status_code <= 299:
+
+                total_profiles = data['total']
+                #print(data)
+
+                for profile in data['data']:
+
+                    if cur_profile % 1000 == 0:
+                        print("{:,}/{:,} ({:.2f}%)".format(
+                            cur_profile, total_profiles, 100.0*float(cur_profile)/total_profiles
+                        ))
+
+                    copernica_id = -1
+                    if 'fields' in profile:
+                        fields = profile['fields']
+                        
+                        copernica_id = int( profile['ID'] )
+                        cemail = self._extract_string(fields, self.fieldnames['email'])
+                        customer_id = self._extract_string(fields, self.fieldnames['Customer_ID'])
+                        cgroup = self._extract_string(fields, self.fieldnames['Group'])
+                        
+                        customer_rows.append((
+                            copernica_id,cemail,
+                            customer_id, cgroup
+                        ))
+                        
+                        if verbose:
+                            print(f"{copernica_id}, {cemail}, {customer_id}, {cgroup}")
+                        
+                    cur_profile = 1 + cur_profile
+            else:
+                cur_profile = page_size + cur_profile
+                print("[link_and_add_to_customers] Call to retrieve {} profiles starting from {} failed.".format(total_profiles, cur_profile))
+
+        print("{:,}/{:,} ({:.2f}%)".format(
+            total_profiles, total_profiles, 100.0, 
+        ))
+
+        df_customers = pd.DataFrame(
+            customer_rows,
+            columns=['Copernica_ID','Email','Customer_ID','Group',]
+        )
+        
+        print(f"Total profiles: {total_profiles:,}")
+
+        return df_customers
\ No newline at end of file
