@@ -96,6 +96,10 @@ class Info(dict):
         
         
     def  __init_dateranges_str(self):
+
+        if len( self['date_ranges'] ) == 0:
+            self.date_range_str = ''
+            return
         
         if self.shorten_date_ranges:
             self.date_range_str = self['date_ranges'][0].split('to')[0] + 'to'+ self['date_ranges'][-1].split('to')[-1]
