@@ -13,11 +13,11 @@ import humailib.utils as hu
 
 class MagentoREST:
     
-    def __init__(self, access_token = 'arayer1r9b1s1r8xjw9mint4l4mjv95o'):
+    def __init__(self, access_token, base_url):
         
         self.access_token = access_token
         #self.base_url = 'https://24fashion.nl/rest/default/V1/'
-        self.base_url = 'https://24fashion.nl/rest/V1/'
+        self.base_url = base_url
                  
     def _get_uri(self, endpoint):
         
@@ -58,9 +58,9 @@ class MagentoREST:
     
 class MagentoOrdersExtract:
     
-    def __init__(self, access_token = 'arayer1r9b1s1r8xjw9mint4l4mjv95o'):
+    def __init__(self, access_token, base_url):
         
-        self.api = MagentoREST(access_token)
+        self.api = MagentoREST(access_token, base_url)
         
     def _extract_field(self, order, field_name):
         
@@ -191,7 +191,11 @@ class MagentoOrdersExtract:
                                     self._extract_field(order,'created_at'), 
                                     self._extract_field(order,'status'),
                                     self._extract_field(order,'store_name'), 
-                                    self._extract_field(order,'store_id')
+                                    self._extract_field(order,'store_id'),
+                                    'product',
+                                    False,
+                                    0.0,
+                                    '',
                                 ]))
 
                                 for item in items:
@@ -206,11 +210,12 @@ class MagentoOrdersExtract:
                                         self._extract_float(item,'original_price'), 
                                         self._extract_float(item,'price'),
                                         self._extract_float(item,'price_incl_tax'),
-                                        1,
+                                        self._extract_float(item,'qty_ordered'),
                                         self._extract_float(item,'tax_amount'), 
                                         self._extract_float(item,'row_total'), 
                                         self._extract_float(item,'row_total_incl_tax'),
-                                        self._extract_field(item,'item_id')
+                                        self._extract_field(item,'item_id'),
+                                        'product',
                                     ]))    
             except:
                 print("Unexpected error: " + sys.exc_info()[0])
@@ -228,7 +233,11 @@ class MagentoOrdersExtract:
             'Datetime', 
             'Status', 
             'Branch_Name', 
-            'Branch_ID'
+            'Branch_ID',
+            'Item_Types',
+            'Voucher_Used',
+            'Voucher_Amount',
+            'Single_Item_Product_ID',
         ])
 
         df_items = pd.DataFrame(item_rows, columns=[ 
@@ -238,7 +247,8 @@ class MagentoOrdersExtract:
             'Original_Price', 'Price', 'Price_Incl_Tax', 
             'Quantity',
             'Tax_Amount', 'Total_Minus_Tax', 'Total',
-            'Item_ID' 
+            'Item_ID',
+            'Item_Type',
         ])
 
         return df_trans, df_items
@@ -246,9 +256,9 @@ class MagentoOrdersExtract:
         
 class MagentoCustomersExtract():
     
-    def __init__(self, access_token = 'arayer1r9b1s1r8xjw9mint4l4mjv95o'):
+    def __init__(self, access_token, base_url):
         
-        self.api = MagentoREST(access_token)
+        self.api = MagentoREST(access_token, base_url)
         self.df_customers = None
         
     def _extract_field(self, customer, field_name):
@@ -353,9 +363,9 @@ class MagentoCustomersExtract():
         
 class MagentoProductsExtract():
     
-    def __init__(self, access_token = 'arayer1r9b1s1r8xjw9mint4l4mjv95o'):
+    def __init__(self, access_token, base_url):
         
-        self.api = MagentoREST(access_token)
+        self.api = MagentoREST(access_token, base_url)
         
     def _extract_field(self, product, field_name):
         
