@@ -26,7 +26,7 @@ class HumaiRankingModel:
             'rf':RandomForestClassifier(n_estimators=200, max_depth=3, random_state=0),
             #'svc':SVC(),  -> slow to train
             #'sgd':SGDClassifier(),
-            'mlp':MLPClassifier(),
+            #'mlp':MLPClassifier(),
             #'nb':MultinomialNB(),
             #'log':LogisticRegression(solver='lbfgs', random_state=0),
         }
