@@ -214,13 +214,14 @@ def load_table(
     check_columns = True,
     flush_cache = True,
     hard_assert = False,
+    use_pandas_gbq = True,
 ):
     """
     Load table and convert column types
     """    
          
     print("[load_table] Loading table...")
-    df = gbq.download_table_to_pandas(dataset_table, flush_cache=flush_cache)
+    df = gbq.download_table_to_pandas(dataset_table, flush_cache=flush_cache, use_pandas_gbq=use_pandas_gbq)
 
     if df is None:
         if hard_assert:
